@@ -54,7 +54,7 @@
 #' @importFrom stats qt na.omit predict terms var qnorm
 #' @importFrom dplyr group_by group_by_at mutate ungroup select distinct
 #' mutate_if if_else summarize_all "%>%" filter_at inner_join anti_join
-#' bind_rows left_join arrange vars summarize
+#' bind_rows left_join arrange vars
 #' @importFrom mrds DeltaMethod
 #' @section Data:
 #' The data format allows for complex stratification schemes to be set-up. Three
@@ -296,6 +296,12 @@ dht2 <- function(ddf, observations=NULL, transects=NULL, geo_strat=NULL,
   ddf <- ddf_proc$ddf
   transect_data <- ddf_proc$transect_data
 
+  # we don't support effort sum or replicate for multiddf
+  if((length(ddf) > 1) &
+     (stratification %in% c("effort_sum", "replicate"))){
+    stop("Effort-sum and replicate stratification not supported with multiple detection functions")
+  }
+
   # grouped estimation
   # time to recurse
   if(!ddf_proc$groupsizeone){
