@@ -17,13 +17,10 @@ flatdat <- merge(flatdat,obs,by=c("Sample.Label","Region.Label"),all.x=TRUE)
 # finally merge the distances onto that
 flatdat <- merge(flatdat,egdata,by="object",all.x=TRUE)
 
-
-
-
-test_that("Recover structure for tee data",{
+test_that("Recover structure for tee data", {
 
   ## check we can recover the 4 data frames
-  sepdat <- Distance:::checkdata(flatdat)
+  sepdat <- unflatten(flatdat)
 
   # this should be a factor really, as is elsewhere
   obs$Region.Label <- as.factor(obs$Region.Label)
@@ -36,23 +33,30 @@ test_that("Recover structure for tee data",{
   expect_equivalent(sepdat$obs.table,obs)
   expect_equivalent(sepdat$sample.table,samples)
   expect_equivalent(sepdat$data,egdata)
-
-
 })
 
-test_that("Errors work",{
+test_that("Errors work", {
 
   flatdat[nrow(flatdat)+1,] <- flatdat[1,]
   flatdat[nrow(flatdat),]$Effort <- 1322
 
-  expect_error(Distance:::checkdata(flatdat))
+  expect_error(unflatten(flatdat))
 
   # check we get an error if the columns are right but their case is wrong
   flatdat$effort <- flatdat$Effort
   flatdat$Effort <- NULL
-  expect_error(Distance:::checkdata(flatdat))
+  expect_error(unflatten(flatdat))
 
 })
+
+test_that("Too many areas given", {
+
+  flatdat$Area[1] <- 123
+
+  expect_error(ds(flatdat), "Region areas are not consistent.")
+
+})
+
 #test_that("Extra regions",{
 #
 #  # add an extra region
